<template>
  <div class="base-page-wrapper">
    <el-bus-form
      ref="form"
      :content="formContent"
      :readonly="!editable"
      label-width="auto"
    ></el-bus-form>
    <div class="text-center mt-20">
      <el-button class="min-w-100" @click="goBack">返回</el-button>
      <el-button
        v-if="editable"
        type="primary"
        :loading="loading"
        class="min-w-100"
        @click="save"
        >保存</el-button
      >
    </div>
  </div>
</template>

<script>
import GoodsParams from '@/components/goods/goods-params.vue'
export default {
  data() {
    return {
      loading: false,
      formContent: [
        {
          type: 'row',
          items: [
            { label: '商品名称：', id: 'name', type: 'input', readonly: true },
            {
              label: '商品分类：',
              id: 'categoryStr',
              type: 'input',
              readonly: true,
            },
            { label: '商品规格：', id: 'unit', type: 'input', readonly: true },
            { label: '级别：', id: 'levelStr', type: 'input', readonly: true },
            { label: '商品售价：', id: 'price', type: 'input', readonly: true },
            {
              label: '销量：',
              id: 'sales',
              type: 'input-number',
              el: { precision: 0, min: 0, style: 'width:100%' },
            },
            { label: '库存：', id: 'stock', type: 'input', readonly: true },
            { label: '商品标签：', id: 'tags', type: 'input', readonly: true },
            {
              label: '所属专区：',
              id: 'zoneName',
              type: 'input',
              readonly: true,
            },
            {
              label: '供应商名称：',
              id: 'supplierName',
              type: 'input',
              readonly: true,
            },
            {
              label: '供应商类型：',
              id: 'supplierType',
              type: 'input',
              readonly: true,
            },
            {
              label: '供应商电话：',
              id: 'supplierTel',
              type: 'input',
              readonly: true,
            },
            {
              label: '商品状态：',
              id: 'status',
              type: 'input',
              str: true,
              readonly: true,
            },
            {
              label: '驳回原因：',
              id: 'auditRemarks',
              type: 'input',
              el: {
                type: 'textarea',
              },
              hidden: (row) => row.status !== 'REJECT',
              readonly: true,
              span: 24,
            },
            {
              label: '列表封面图片：',
              id: 'cover',
              type: 'bus-upload',
              el: {
                listType: 'picture-card',
                valueType: 'string',
              },
              forceDisabled: true,
              span: 24,
              readonly: true,
            },
            {
              label: '轮播图：',
              id: 'bannerList',
              type: 'bus-upload',
              el: {
                listType: 'picture-card',
              },
              forceDisabled: true,
              span: 24,
              inputFormat: (row) => {
                if ('bannerList' in row) {
                  return Array.isArray(row.bannerList)
                    ? row.bannerList.map((item) => ({ url: item }))
                    : []
                }
              },
              readonly: true,
            },
            {
              label: '商品参数：',
              id: 'params',
              component: GoodsParams,
              span: 24,
              forceDisabled: true,
              el: {
                style: 'width:50%',
              },
            },
          ],
        },
      ],
    }
  },
  head() {
    return {
      title: this.title,
    }
  },
  computed: {
    title() {
      return this.$route.params.action === 'edit' ? '编辑商品' : '商品详情'
    },
    editable() {
      return this.$route.params.action === 'edit'
    },
  },
  mounted() {
    this.getDetail()
  },
  methods: {
    async getDetail() {
      this.loading = true
      const { code, data } = await this.$elBusHttp.request(
        'flower/api/flower/list/view',
        { params: { id: this.$route.params.id } }
      )
      if (code === 0) {
        this.$refs.form.updateForm(data)
      }
      this.loading = false
    },
    goBack() {
      this.$router.back()
    },
    async save() {
      this.loading = true
      const formValue = this.$refs.form.getFormValue()
      const { code } = await this.$elBusHttp.request(
        'flower/api/flower/list/edit',
        {
          method: 'post',
          data: { ...formValue, id: this.$route.params.id },
        }
      )
      if (code === 0) {
        this.$message.success('保存成功')
        this.goBack()
      } else {
        this.loading = false
      }
    },
  },
}
</script>
